#!/bin/bash
#
# This is a bash port of Davids and Arnes "TelliCastStatsColletor.cmd"
# CRON: Uses a line like this to execute the script at minutes 29 & 59
# 29,59 * * * * root /root/TelliCastStatsCollector.sh > /dev/null 2>&1
#
# Version 1.0     March 11th 2016    (c) Ernst Lobsiger    License GPL
#

# BEGIN of Parameter Section >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
#
# This should run locally on an EumetCast receiver or over a network from
# a central statistics collection PC. No name to IP resolution is assumed.
# If you set interface_address=eth0 in cast-client.ini then localhost will
# not work and you have to set MyIP to the address of your interface eth0.
#
Node=`hostname`
MyIP="localhost"
Port="2517"
StatsDir="/var/www/packets"
####="<---Describe your system. But do not make your text longer than this! --->"
Recv="Quad Inverto Black Ultra, TBS6908 PCIe card, TelliCast client(s) 2.12.1-11"
Desc="Receives BS+HVS + does image and film processing ...      (BS stats shown)"
#
####="<---This is a delimiter. You may change the character but length must be 80 --->"
Deli="--------------------------------------------------------------------------------"
#
# <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< END of Parameter Section


# FUNCTIONS() as used by David and Arne go on top

NewDay()
{
  echo "$Deli" > $File
  echo "TelliCastStatsCollector.sh  (A script for GNU/Linux)                 Version 1.0" >> $File
  echo "(c) David Taylor, Arne van Belle, and Ernst Lobsiger                 License GPL" >> $File
  echo "" >> $File
  echo "HOST: $Node" >> $File
  echo "RECV: $Recv" >> $File
  echo "DESC: $Desc" >> $File
  echo "$Deli" >> $File
  echo "YearMonDay   -UTC-    Missed    Recov.      Lost      Received          Received" >> $File
  echo "YYYY-MM-DD   hh:mm   Packets   Packets   Packets       Packets             Bytes" >> $File
}

AddLine()
{
  # AddLine assumes that you use TelliCast client 2.12.1-11 or later
  Line="http://$MyIP:$Port/www/tsl/receiver/tsl_receiver_statistics.html"
  Line=`w3m -dump $Line`
  Pack=`echo "$Line" | awk '/Received.P/ {print $6}'`
  Miss=`echo "$Line" | awk '/Missed/ {print $5}'`
  Reco=`echo "$Line" | awk '/Recovered/ {print $4}'`
  Byte=`echo "$Line" | awk '/Received.B/ {print $6}'`
  Lost=$(( Miss - Reco ))
  # Formated output must exactly fit header produced by function NewDay()!
  Line="$Date   $Time   `Nice $Miss 7`   `Nice $Reco 7`   `Nice $Lost 7`   `Nice $Pack 11`   `Nice $Byte 15`"
  echo "$Line" >> $File
}

Nice()
{
  # Format big numbers nice
  Tail=""
  Numb="                $1"
  Lead=${Numb:(-4):(-3)}
  while [ "$Lead" != " " ]
  do
    Tail=\'${Numb:(-3)}$Tail
    Numb=${Numb:0:(-3)}
    Lead=${Numb:(-4):(-3)}
  done
  Numb=$Numb$Tail
  echo "${Numb:(-$2)}"
}

MidnightReset()
{
  Line="http://$Node:$Port/www/tsl/receiver/reset_tc_statistics.cgi"
  wget -t 3 -O /dev/null 2>&1 $Line
  echo "$Deli" >> $File
}


# The MAIN() part of the script goes at the bottom

# Sets the environment Date/Time variables in UTC
Line=`date -u +%Y-%m-%d' '%R`
# Get all variables from one date system call only
Date=`echo $Line | cut -d' ' -f1`
Time=`echo $Line | cut -d' ' -f2`
# Set name of output file for all output of script
File="$StatsDir/TCstats_$Node""_BS_$Date.txt"

if [ $Time = '00:29' ]; then NewDay; fi

AddLine

if [ $Time = '23:59' ]; then MidnightReset; fi

